==> jwinner-kit-0.0.3-sources.jar: itez/kit/EHttp.java <==
package itez.kit;

import okhttp3.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Maps;

import java.io.File;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * HTTP操作工具类
 * 
 * @author netwild
 *
 */
public class EHttp {

	private final static Logger log = LoggerFactory.getLogger(EHttp.class);
	public final static EHttp me = new EHttp();
	
	public static enum Method { GET, POST, PUT, DELETE, PATCH }
	private final static Charset CharSet = Charset.forName("UTF-8");
	private static final MediaType ContentType = MediaType.parse("application/octet-stream");
	private final HashMap<String, List<Cookie>> cookieStore = new HashMap<>();
	
	private OkHttpClient client;
	
	private EHttp(){
		Dispatcher dispatcher = new Dispatcher();
        dispatcher.setMaxRequests(64); //底层HTTP库所有的并发执行的请求数量
        dispatcher.setMaxRequestsPerHost(16); //底层HTTP库对每个独立的Host进行并发请求的数量
        //连接池：底层HTTP库中复用连接对象的最大空闲数量（默认32），底层HTTP库中复用连接对象的回收周期（默认5分钟）
		ConnectionPool connectionPool = new ConnectionPool(32, 5, TimeUnit.MINUTES);
		client = new OkHttpClient.Builder()
				.dispatcher(dispatcher)
				.connectionPool(connectionPool) //连接池
				.connectTimeout(10, TimeUnit.SECONDS) //连接超时，默认10秒
				.readTimeout(30, TimeUnit.SECONDS) //读取超时，默认30秒
				.writeTimeout(0,TimeUnit.SECONDS) //写入超时，0为不超时
				.cookieJar(new CookieJar(){ //自动携带Cookie，并回写到本地
					@Override
					public void saveFromResponse(HttpUrl url, List<Cookie> cookies) {
						cookieStore.put(url.host(), cookies);
					}
					@Override
					public List<Cookie> loadForRequest(HttpUrl url) {
						List<Cookie> cookies = cookieStore.get(url.host());
						return cookies != null ? cookies : new ArrayList<Cookie>();
					}
				})
				.build();
	}

	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String get(String url){
		Request request = httpBuilder(Method.GET, url, null, null);
		return execute(request);
	}

	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String get(String url, Map<String, String> params){
		url = formatGetParams(url, params);
		Request request = httpBuilder(Method.GET, url, null, null);
		return execute(request);
	}
	
	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @param headers
	 * @return
	 */
	public String get(String url, Map<String, String> params, Map<String, String> headers){
		url = formatGetParams(url, params);
		Request request = httpBuilder(Method.GET, url, headers, null);
		return execute(request);
	}
	
	/**
	 * 将get请求中的参数列表转换为字符串附加到url
	 * @param url
	 * @param params
	 * @return
	 */
	private String formatGetParams(String url, Map<String, String> params){
		String paramsStr = "";
		if(params != null && !params.isEmpty()) {
			paramsStr = params.entrySet().stream()
					.map(e -> String.format("%s=%s", e.getKey(), e.getValue()))
					.collect(Collectors.joining("&"));
		}
		if(EStr.notEmpty(paramsStr)){
			url = String.format("%s%s%s", url, url.indexOf("?") > 0 ? '&' : '?', paramsStr);
		}
		return url;
	}
	
	/**
	 * @category Post Json请求
	 * @param url
	 * @param json
	 * @return
	 */
	public String postJson(String url, String json){
		MediaType mediaType = MediaType.parse(String.format("application/json; charset=%s", CharSet));
		RequestBody data = RequestBody.create(mediaType, json);
		Request request = httpBuilder(Method.POST, url, null, data);
		return execute(request);
	}

	/**
	 * @category Post Json请求
	 * @param url
	 * @param json
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postJson(String url, String json, Map<String, String> headers){
		MediaType mediaType = MediaType.parse(String.format("application/json; charset=%s", CharSet));
		RequestBody data = RequestBody.create(mediaType, json);
		Request request = httpBuilder(Method.POST, url, headers, data);
		return execute(request);
	}
	
	/**
	 * @category Post Form请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String postForm(String url, Map<String, String> params){
		FormBody.Builder builder = getFormBody(params);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post Form请求
	 * @param url
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postForm(String url, Map<String, String> params, Map<String, String> headers){
		FormBody.Builder builder = getFormBody(params);
		Request request = httpBuilder(Method.POST, url, headers, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @return
	 */
	public String postFile(String url, Map<String, File> files){
		MultipartBody.Builder builder = getMultiBody(files, null);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @param params
	 * @return
	 */
	public String postFile(String url, Map<String, File> files, Map<String, String> params){
		MultipartBody.Builder builder = getMultiBody(files, params);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postFile(String url, Map<String, File> files, Map<String, String> params, Map<String, String> headers){
		MultipartBody.Builder builder = getMultiBody(files, params);
		Request request = httpBuilder(Method.POST, url, headers, builder.build());
		return execute(request);
	}
	
	/**
	 * @category 生成FormBody.Builder
	 * @param params
	 * @return
	 */
	private FormBody.Builder getFormBody(Map<String, String> params){
		FormBody.Builder builder = new FormBody.Builder(CharSet);
		if(params != null && !params.isEmpty()) {
			params.forEach((k, v) -> builder.add(k, v));
		}
		return builder;
	}
	
	/**
	 * @category 生成MultipartBody.Builder
	 * @param files
	 * @param params
	 * @return
	 */
	private MultipartBody.Builder getMultiBody(Map<String, File> files, Map<String, String> params){
		MultipartBody.Builder builder = new MultipartBody.Builder();
		builder.setType(MultipartBody.FORM);
		if(files != null && !files.isEmpty()) {
			files.forEach((k, v) -> builder.addFormDataPart(k, v.getName(), getFileBody(v)));
		}
		if(params != null && !params.isEmpty()) {
			params.forEach((k, v) -> builder.addFormDataPart(k, v));
		}
		return builder;
	}
	
	/**
	 * @category 生成文件数据体
	 * @param file
	 * @return
	 */
	private RequestBody getFileBody(File file){
		RequestBody fileBody = RequestBody.create(ContentType, file);
		return fileBody;
	}
	
	/**
	 * @category 生成请求主体
	 * @param method 请求类型
	 * @param url 请求地址
	 * @param headers 请求头
	 * @param params 参数
	 * @param data 数据
	 * @return
	 */
	private Request httpBuilder(Method method, String url, Map<String, String> headers, RequestBody data) {
		Request.Builder builder = new Request.Builder();
		builder.url(url);		
		builder.header("User-Agent", "JWinner EHttp Kit");
		builder.addHeader("Accept-Charset", CharSet.toString());
		builder.addHeader("Accept-Language", "en-us,zh-ch");
		builder.addHeader("Content-Type", String.format("text/html; charset=%s;", CharSet));
		if(headers != null && !headers.isEmpty() && headers.size() > 0) {
			headers.forEach((k, v) ->  builder.addHeader(k, v));
		}
		if(method == Method.GET){
			builder.get();
		}else{
			builder.method(method.name(), data);
		}
		Request req = builder.build();
		return req;
	}
	
	/**
	 * @category 执行请求
	 * @param request
	 * @return
	 */
	private String execute(Request request){
		String result = "";
		try {
			Response response = client.newCall(request).execute();
			if(response.isSuccessful()){
				result = response.body().string();
			}else{
				log.error("请求失败：{}", response.toString());
			}
		} catch (Exception e) {
			log.error("请求错误：{}", e.getMessage());
		}
		return result;
	}
	
	@SuppressWarnings("unused")
	public static void main(String[] args) {
		Map<String, String> params = Maps.newHashMap();
		params.put("uid", "abc");
		params.put("uname", "王婆卖瓜");
		
		Map<String, String> headers = Maps.newHashMap();
		headers.put("header", "xxx");
		headers.put("cook", "cookvalue");
		
		Map<String, File> files = Maps.newHashMap();
		files.put("file001", new File("D:\\WxAppRoot\\jyt\\resources\\topHeader.jpg"));
		files.put("file002", new File("D:\\公司资料\\业务价格清单.xlsx"));
		
		//String ret = EHttp.me.get("http://localhost/plat/testGet", params, headers);
		//String ret = EHttp.me.postForm("http://localhost/testForm", params, headers);
		
		String ret = EHttp.me.postFile("http://localhost/testFiles", files);
		//System.out.println(ret);
	}
	
}

==> jwinner-kit-0.0.9-sources.jar: itez/kit/EHttp.java <==
package itez.kit;

import okhttp3.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Maps;

import java.io.File;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * HTTP操作工具类
 * 
 * @author netwild
 *
 */
public class EHttp {

	private final static Logger log = LoggerFactory.getLogger(EHttp.class);
	public final static EHttp me = new EHttp();
	
	public static enum Method { GET, POST, PUT, DELETE, PATCH }
	private final static Charset CharSet = Charset.forName("UTF-8");
	private static final MediaType ContentType = MediaType.parse("application/octet-stream");
	private final HashMap<String, List<Cookie>> cookieStore = new HashMap<>();
	
	private OkHttpClient client;
	
	private EHttp(){
		Dispatcher dispatcher = new Dispatcher();
        dispatcher.setMaxRequests(64); //底层HTTP库所有的并发执行的请求数量
        dispatcher.setMaxRequestsPerHost(16); //底层HTTP库对每个独立的Host进行并发请求的数量
        //连接池：底层HTTP库中复用连接对象的最大空闲数量（默认32），底层HTTP库中复用连接对象的回收周期（默认5分钟）
		ConnectionPool connectionPool = new ConnectionPool(32, 5, TimeUnit.MINUTES);
		client = new OkHttpClient.Builder()
				.dispatcher(dispatcher)
				.connectionPool(connectionPool) //连接池
				.connectTimeout(10, TimeUnit.SECONDS) //连接超时，默认10秒
				.readTimeout(30, TimeUnit.SECONDS) //读取超时，默认30秒
				.writeTimeout(0,TimeUnit.SECONDS) //写入超时，0为不超时
				.cookieJar(new CookieJar(){ //自动携带Cookie，并回写到本地
					@Override
					public void saveFromResponse(HttpUrl url, List<Cookie> cookies) {
						cookieStore.put(url.host(), cookies);
					}
					@Override
					public List<Cookie> loadForRequest(HttpUrl url) {
						List<Cookie> cookies = cookieStore.get(url.host());
						return cookies != null ? cookies : new ArrayList<Cookie>();
					}
				})
				.build();
	}

	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String get(String url){
		Request request = httpBuilder(Method.GET, url, null, null);
		return execute(request);
	}

	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String get(String url, Map<String, String> params){
		url = formatGetParams(url, params);
		Request request = httpBuilder(Method.GET, url, null, null);
		return execute(request);
	}
	
	/**
	 * @category Get请求
	 * @param url
	 * @param params
	 * @param headers
	 * @return
	 */
	public String get(String url, Map<String, String> params, Map<String, String> headers){
		url = formatGetParams(url, params);
		Request request = httpBuilder(Method.GET, url, headers, null);
		return execute(request);
	}
	
	/**
	 * 将get请求中的参数列表转换为字符串附加到url
	 * @param url
	 * @param params
	 * @return
	 */
	private String formatGetParams(String url, Map<String, String> params){
		String paramsStr = "";
		if(params != null && !params.isEmpty()) {
			paramsStr = params.entrySet().stream()
					.map(e -> String.format("%s=%s", e.getKey(), e.getValue()))
					.collect(Collectors.joining("&"));
		}
		if(EStr.notEmpty(paramsStr)){
			url = String.format("%s%s%s", url, url.indexOf("?") > 0 ? '&' : '?', paramsStr);
		}
		return url;
	}
	
	/**
	 * @category Post Json请求
	 * @param url
	 * @param json
	 * @return
	 */
	public String postJson(String url, String json){
		MediaType mediaType = MediaType.parse(String.format("application/json; charset=%s", CharSet));
		RequestBody data = RequestBody.create(mediaType, json);
		Request request = httpBuilder(Method.POST, url, null, data);
		return execute(request);
	}

	/**
	 * @category Post Json请求
	 * @param url
	 * @param json
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postJson(String url, String json, Map<String, String> headers){
		MediaType mediaType = MediaType.parse(String.format("application/json; charset=%s", CharSet));
		RequestBody data = RequestBody.create(mediaType, json);
		Request request = httpBuilder(Method.POST, url, headers, data);
		return execute(request);
	}
	
	/**
	 * @category Post Form请求
	 * @param url
	 * @param params
	 * @return
	 */
	public String postForm(String url, Map<String, String> params){
		FormBody.Builder builder = getFormBody(params);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post Form请求
	 * @param url
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postForm(String url, Map<String, String> params, Map<String, String> headers){
		FormBody.Builder builder = getFormBody(params);
		Request request = httpBuilder(Method.POST, url, headers, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @return
	 */
	public String postFile(String url, Map<String, File> files){
		MultipartBody.Builder builder = getMultiBody(files, null);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @param params
	 * @return
	 */
	public String postFile(String url, Map<String, File> files, Map<String, String> params){
		MultipartBody.Builder builder = getMultiBody(files, params);
		Request request = httpBuilder(Method.POST, url, null, builder.build());
		return execute(request);
	}
	
	/**
	 * @category Post File 请求
	 * @param url
	 * @param files
	 * @param params
	 * @param headers
	 * @return
	 */
	public String postFile(String url, Map<String, File> files, Map<String, String> params, Map<String, String> headers){
		MultipartBody.Builder builder = getMultiBody(files, params);
		Request request = httpBuilder(Method.POST, url, headers, builder.build());
		return execute(request);
	}
	
	/**
	 * @category 生成FormBody.Builder
	 * @param params
	 * @return
	 */
	private FormBody.Builder getFormBody(Map<String, String> params){
		FormBody.Builder builder = new FormBody.Builder(CharSet);
		if(params != null && !params.isEmpty()) {
			params.forEach((k, v) -> builder.add(k, v));
		}
		return builder;
	}
	
	/**
	 * @category 生成MultipartBody.Builder
	 * @param files
	 * @param params
	 * @return
	 */
	private MultipartBody.Builder getMultiBody(Map<String, File> files, Map<String, String> params){
		MultipartBody.Builder builder = new MultipartBody.Builder();
		builder.setType(MultipartBody.FORM);
		if(files != null && !files.isEmpty()) {
			files.forEach((k, v) -> builder.addFormDataPart(k, v.getName(), getFileBody(v)));
		}
		if(params != null && !params.isEmpty()) {
			params.forEach((k, v) -> builder.addFormDataPart(k, v));
		}
		return builder;
	}
	
	/**
	 * @category 生成文件数据体
	 * @param file
	 * @return
	 */
	private RequestBody getFileBody(File file){
		RequestBody fileBody = RequestBody.create(ContentType, file);
		return fileBody;
	}
	
	/**
	 * @category 生成请求主体
	 * @param method 请求类型
	 * @param url 请求地址
	 * @param headers 请求头
	 * @param params 参数
	 * @param data 数据
	 * @return
	 */
	private Request httpBuilder(Method method, String url, Map<String, String> headers, RequestBody data) {
		Request.Builder builder = new Request.Builder();
		builder.url(url);		
		builder.header("User-Agent", "JWinner EHttp Kit");
		builder.addHeader("Accept-Charset", CharSet.toString());
		builder.addHeader("Accept-Language", "en-us,zh-ch");
		builder.addHeader("Content-Type", String.format("text/html; charset=%s;", CharSet));
		if(headers != null && !headers.isEmpty() && headers.size() > 0) {
			headers.forEach((k, v) ->  builder.addHeader(k, v));
		}
		if(method == Method.GET){
			builder.get();
		}else{
			builder.method(method.name(), data);
		}
		Request req = builder.build();
		return req;
	}
	
	/**
	 * @category 执行请求
	 * @param request
	 * @return
	 */
	private String execute(Request request){
		String result = "";
		try {
			Response response = client.newCall(request).execute();
			if(response.isSuccessful()){
				result = response.body().string();
			}else{
				log.error("请求失败：{}", response.toString());
			}
		} catch (Exception e) {
			log.error("请求错误：{}", e.getMessage());
		}
		return result;
	}
	
	public static void main(String[] args) {
		Map<String, String> params = Maps.newHashMap();
		params.put("uid", "abc");
		params.put("uname", "王婆卖瓜");
		
		Map<String, String> headers = Maps.newHashMap();
		headers.put("JWSID", "eyJhbGciOiJIUzUxMiJ9.eyJqdGkiOiJaWlQ2SVJEMjAxWUkzRE4yMFUifQ.jjtlLh9An_HF4Wp7xhwLvxipbeLKf60Fx368-zWShOT0SXzMzNClauaiC5nkO4wRBWI0aJxb-fNyuAOwpsKYjA");
		
		Map<String, File> files = Maps.newHashMap();
		files.put("file001", new File("D:\\WxAppRoot\\jyt\\resources\\topHeader.jpg"));
		files.put("file002", new File("D:\\公司资料\\业务价格清单.xlsx"));
		
		String ret = EHttp.me.get("http://localhost/www/plat/", null, headers);
		System.out.println(ret);
		//String ret = EHttp.me.postForm("http://localhost/testForm", params, headers);
		
		//String ret = EHttp.me.postFile("http://localhost/testFiles", files);
		//System.out.println(ret);
	}
	
}
